#{----------------------------------------------------------------------------
# Copyright 2009,2012 Jakub Kupikowski
#
# License: 
# Free for self use
# Permission to sell or redistribute or repackage this software 
# should be specifically requested from the author.
# above copyright notice should appear in all copies.
#
# THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
#
# ----------------------------------------------------------------------------
#
# Author: Jakub Kupikowski
#
# Name: simple_rays.rb
#
# Description: Textures model according to chosen raytest method.
#		
# Usage   : Selection > Right Mouse Click > Raytest
#		 
# Install : Install rbz archive using "Install Extension..." utility, from:
#            Window (menu) > Preferences (menuitem) > Extensions (panel)
#
# ----------------------------------------------------------------------------
# VERSION INFORMATION: see "Qpik/SimpleRays/simple_rays.rb" file header
# ----------------------------------------------------------------------------
#
#  THIS FILE MUST BE SAVED IN ENCODING:  "UTF-8 WITHOUT BOM"  <-- !!!!!!!!!!!!
#
# ----------------------------------------------------------------------------


module Qpik  # <--<< Jakub Kupikowski's proprietary toplevel namespace

  module SimpleRays    # <--<< THIS plugin's nested namespace

    require('sketchup.rb')
    require('extensions.rb')

    # Register plugin as an extension.
    @@plugin = SketchupExtension.new('SimpleRays', File.join(File.dirname(__FILE__), 'Qpik/SimpleRays/simple_rays.rb'))
    @@plugin.version = '1.0.1'
    @@plugin.creator = 'Jakub Kupikowski'
    @@plugin.copyright = '2009,2012 by author'

    @@lang = Sketchup.get_locale()[0,2]

    if @@lang=='en' # English
      @@plugin.description = 'SimpleRays: Textures selected faces according to chosen raytest method: Sun Exposure Time or Ambient Occlusion.'
    elsif @@lang=='cs' # Czech
      @@plugin.description = 'SimpleRays (ProstýPaprsky): Textury vybrané tváře podle zvolené ray zkušební metoda: Solární Doba Expozice nebo Ambientní Okluze.'
    elsif @@lang=='de' # German
      @@plugin.description = 'SimpleRays (SimpelStrahlen): Texturen ausgewählten Flächen entsprechend der gewählten Strahl-Test Methode: Sonne Belichtungszeit oder Umgebungs-Okklusion.'
    elsif @@lang=='es' # Spanish
      @@plugin.description = 'SimpleRays (RayosSimples): Caras seleccionadas de texturas según elegido ray-prueba método: Tiempo de Exposición del Sol o Oclusión Ambiental.'
    elsif @@lang=='fr' # French
      @@plugin.description = %q{SimpleRays (RayonsSimples): Faces sélectionnées de Textures selon choisi ray-test méthode: Temps d'Exposition au Soleil ou Occlusion Ambiante.}
    elsif @@lang=='it' # Italian
      @@plugin.description = %q{SimpleRays (SempliciRaggi): Facce selezionate texture secondo scelto ray-test Metodo: Tempo di Esposizione del Sole o Occlusione Ambientale.}
    elsif @@lang=='nl' # Dutch
      @@plugin.description = 'SimpleRays (SimpelStralen): Texturen geselecteerde gezichten volgens gekozen ray-test methode: Zon Belichtingstijd of Omgevings-Occlusie.'
    elsif @@lang=='pl' # Polish
      @@plugin.description = 'SimpleRays (ProstePromienie): Wybrane ściany tekstury zgodnie z wybranym promień badania Metoda: Czas Ekspozycji Słońca lub Okluzja Otoczenia.'
    elsif @@lang=='pt' # Portuguese
      @@plugin.description = 'SimpleRays (RaiosSimples): Ray-teste de faces selecionadas de texturas de acordo com o escolhido método: Tempo de Exposição do Sol ou Oclusão de Ambiente.'
    elsif @@lang=='ru' # Russian
      @@plugin.description = 'SimpleRays (Простые-лучей): Текстуры выбранного лица согласно выбранной Рэй тест метод: Солнечное время экспозиции или Oкружающего Окклюзия.'
    else # English
      @@plugin.description = 'SimpleRays: Textures selected faces according to chosen raytest method: Sun Exposure Time or Ambient Occlusion.'
    end

    Sketchup.register_extension(@@plugin, true)

  end # module SimpleRays

end # module Qpik

# ... "Look Mom! No code outside the author's namespaces."